.. SPDX-FileCopyrightText: 2020-2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.prov package
=====================

Modules
-------
.. toctree::
   :maxdepth: 1

   prov/oc_ocdm.prov.prov_entity
   prov/oc_ocdm.prov.prov_set

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   prov/oc_ocdm.prov.entities
